@@ -3,6 +3,7 @@ package Params::Validate::Strict;
 use strict;
 use warnings;
 use Carp;
+use Params::Get;
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(validate_strict);
@@ -13,11 +14,11 @@ Params::Validate::Strict - Validates a set of parameters against a schema
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -51,11 +52,11 @@ This function takes two mandatory arguments:
 
 =over 4
 
-=item * C<$schema>
+=item * C<schema>
 
 A reference to a hash that defines the validation rules for each parameter.  The keys of the hash are the parameter names, and the values are either a string representing the parameter type or a reference to a hash containing more detailed rules.
 
-=item * C<$args>
+=item * C<args>
 
 A reference to a hash containing the parameters to be validated.  The keys of the hash are the parameter names, and the values are the parameter values.
 
@@ -65,7 +66,7 @@ It takes one optional argument:
 
 =over 4
 
-=item * C<$unknown_parameter_handler>
+=item * C<unknown_parameter_handler>
 
 This parameter describes what to do when a parameter is given that is not in the schema of valid parameters.
 It must be one of C<die> (the default), C<warn>, or C<ignore>.
@@ -113,7 +114,7 @@ If the validation is successful, the function will return a reference to a new h
 
 sub validate_strict
 {
-	my $params = _get_params(undef, @_);
+	my $params = Params::Get::get_params(undef, @_);
 
 	my $schema = $params->{'schema'};
 	my $args = $params->{'args'};
@@ -221,7 +222,7 @@ sub validate_strict
 						croak(__PACKAGE__, "::validate_strict: Parameter '$key' has meaningless max value $rule_value");
 					}
 				} elsif($rule_name eq 'matches') {
-					unless ($value =~ $rule_value) {
+					unless($value =~ $rule_value) {
 						croak "validate_strict: Parameter '$key' must match '$rule_value'";
 					}
 				} elsif ($rule_name eq 'callback') {
@@ -246,39 +247,6 @@ sub validate_strict
 	return \%validated_args;
 }
 
-# Helper routine to parse the arguments given to a function.
-# Processes arguments passed to methods and ensures they are in a usable format,
-#	allowing the caller to call the function in anyway that they want
-#	e.g. foo('bar'), foo(arg => 'bar'), foo({ arg => 'bar' }) all mean the same
-#	when called _get_params('arg', @_);
-sub _get_params
-{
-	my $default = shift;
-
-	# Directly return hash reference if the first parameter is a hash reference
-	return $_[0] if(ref($_[0]) eq 'HASH');
-
-	my %rc;
-	my $num_args = scalar(@_);
-
-	# Populate %rc based on the number and type of arguments
-	if(($num_args == 1) && defined($default)) {
-		# %rc = ($default => shift);
-		return { $default => shift };
-	} elsif($num_args == 1) {
-		Carp::croak('Usage: ', __PACKAGE__, '->', (caller(1))[3], '()');
-	} elsif(($num_args == 0) && defined($default)) {
-		Carp::croak('Usage: ', __PACKAGE__, '->', (caller(1))[3], "($default => \$val)");
-	} elsif(($num_args % 2) == 0) {
-		%rc = @_;
-	} elsif($num_args == 0) {
-		return;
-	} else {
-		Carp::croak('Usage: ', __PACKAGE__, '->', (caller(1))[3], '()');
-	}
-
-	return \%rc;
-}
 =head1 AUTHOR
 
 Nigel Horne, C<< <njh at bandsman.co.uk> >>
@@ -289,6 +257,8 @@ Nigel Horne, C<< <njh at bandsman.co.uk> >>
 
 =over 4
 
+=item * L<Params::Get>
+
 =item * L<Params::Validate>
 
 =back
